/* 
 * vflmklib.h 
 *
 * by Hirotsugu Kakugawa
 *
 *  10 May 2001
 */
/*
 * Copyright (C) 2001  Hirotsugu Kakugawa. 
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
 */

#ifndef  __VFLIBMKLIB_H__
#define __VFLIBMKLIB_H__

extern char*  copy_cmdline(int,char**);
extern void   banner(char*,char*,char*);
extern char*  x_strdup(char*);
extern char*  check_font_exist(char*,char**,int,int,char**);
extern void   check_argc(int);
extern int    map_need_tfm(char*);

#endif /* __VFLIBMKLIB_H__ */

